/*  screen.css for nirlo 

    derived from
    screen.css - MoinMoin Default Styles
    Copyright (c) 2001, 2002, 2003 by Jürgen Hermann
    
    2004 modified heavily by Niklas Gidion 
*/

h1 {
	padding: .2em 1em;
    font-size: 1.4em;
    font-weight: bold;
    margin-top:0em;
    margin-bottom:1.8em;
}

h2, h3, h4, h5, h6, #Header {
	background-color: #CCCCFF;
	color: black;
    padding-left:5px;
    border-bottom:1px solid #666666;
    border-right:1px solid #666666;
    border-top:1px solid #AAAACC;
    border-left:1px solid #AAAACC;
}	

a:link {
	background-color: inherit;
	color: #333333;
	text-decoration: underline;
}

a:visited {
	background-color: inherit;
	color: black;
	text-decoration: underline;
}

a:hover {
    background-color: inherit;
	color: black;
	text-decoration: none;
}

a.nonexistent, a.badinterwiki {
	background-color: inherit;
	color: #CC0066;
}

pre {
	border: 1px solid #CBCBCB;
	background-color: white;
	color: #333;
    padding: 5px;
    white-space: pre-wrap;   
    white-space: -o-pre-wrap; 
    white-space: -moz-pre-wrap; 
}

pre>table {
    font-size: 1em;
}

hr {
	clear: both;
	border-style: none;
	background-color: #CBCBCB;
	color: #CBCBCB;
}

td {
	border: 1px solid #EEEEEE;
}

table {
    /* table cells tend to get too wide and thus collide with the sidebar - so
       lets make the font a bit smaller for tables in general */ 
    font-size: small;
}

.footnotes div {
	width: 5em;
	border-top: 1px solid #CBCBCB;
}


#logo {
	float: left;
	margin: 0em .5em;
	padding: 0em;
}

*[dir="rtl"] #logo {
	float: right;
}

#username {
	text-align: left;
}

*[dir="rtl"] #username {
	text-align: right;
}

#navibar {
	clear: left;
}

*[dir="rtl"] #navibar {
	clear: right;
}

#pagetrail {
	clear: left;
}

*[dir="rtl"] #pagetrail {
	clear: right;
}

#navibar, #pagetrail, #iconbar {
	margin: .5em 0;
	padding: 0;
}

#navibar a:hover {
        text-decoration: none;
}

#navibar, #pagetrail a {
	text-decoration: none;
}

#navibar a, #pagetrail li, #iconbar li {
	display: inline;
	padding: 0 2px;
	margin: 0;
}

#navibar a {
	padding: 1px;
	color: black;
	text-decoration: underline;
}

#pagetrail span {
	color: black;
	text-decoration: underline;
}

#pagetrail span:hover {
        text-decoration: none;
}

#pagetrail span:before {
	content: "» ";
}

*[dir="rtl"] #pagetrail span:before {
	content: " «";
}

#credits {
	float: right;
	text-align: right;
	max-width: 90%;
}

*[dir="rtl"] #credits {
	float: left;
	text-align: left;
}

#timings {
	padding: 0;
	font-size: 0.8em;
}

#timings li {
	display: inline;
	background-color: #E5E5E5;
	color: black;
}

#preview {
	border: 2px solid #CBCBCB;
	padding: .5em;
	background: url(../img/draft.png);
}

.recentchanges table {
	width: 100%;
}

#pageinfo td, .recentchanges td {
	padding: 0 .3em;
}

.rcdaybreak td {
	background-color: #CCCCFF;
	padding: .2em;
    border-bottom:1px solid #666666;
    border-right:1px solid #666666;
    border-top:1px solid #AAAACC;
    border-left:1px solid #AAAACC;
}

.rcicon1, .rcicon2 {
	text-align: center;
}

.rcpagelink {
	width: 33%;
}

.rctime {
	font-size: .9em;
	color: #4D4D4D;
}

.rceditor {
	color: green;
}

.rccomment {
	color: red;
	width: 66%;
}

.rcrss {
	float: right;
}

.recentchanges[dir="rtl"] .rcrss {
	float: left;
}

.diff {
        width:99%;
}
    
.diff-title {
	background-color: #C0C0C0;
}

.diff-added {
	background-color: #E0FFE0;
	vertical-align: sub;
}

.diff-removed {
	background-color: #FFFFE0;
	vertical-align: sub;
}

.diff-added span {
	background-color: #80FF80;
}

.diff-removed span {
	background-color: #FFFF80;
}

.searchresult dd span {
	font-weight: bold;
}

#iconbar {
	clear: both;
	float: right;
}

*[dir="rtl"] #iconbar {
	float: right;
	text-align: right;
}

#Icons {
    position:absolute;
    top:2.3em;
    float: right;
    padding:8px;
}

#sidebar {
    font-size:0.7em;
    background-color: #E5E5E5;
    position:absolute;
    top:8em;
    right:.8em;
    text-align: left;
    padding:5px;
    width:12.5em;
	border-left: 1px solid #CBCBCB;
	border-top: 1px solid #CBCBCB;
	border-right: 1px solid #666666;
	border-bottom: 1px solid #666666;
}

body>#sidebar {
    width:13em;
}


#username {
    text-indent:0px;
    padding-left:.2em;
    }

#Search {
    }

#Menu {
    padding-left:.2em;
    }


#actionsidebar {
    text-indent:0px;
    padding-left:.2em;
    padding-bottom:.2em;
    white-space: normal;
    }

#lastpages {
    text-indent:0px;
    padding-left:.2em;
    white-space: normal;
    }

#Header {
    margin:2px 0px 0px 0px;
    padding: 2px 0px 1em 0px;
    height:3.3em;
    text-align: left;
    voice-family: "\"}\"";
    voice-family:inherit;
    }
body>#Header {height:3.3em;}

#content {
    margin:5px 10.5em 0px 0px;
    text-align:left;
}

#content>div {margin-left: 0px; }
#content>p {
    margin:0px;
    margin-bottom:1em;
}

#content>p+p {
    text-indent:0px;
}

#message, #footer {
	clear: both;
	background-color: #E5E5E5;
	border-left: 1px solid #CBCBCB;
	border-top: 1px solid #CBCBCB;
	border-right: 1px solid #666666;
	border-bottom: 1px solid #666666;
	color: black;
	padding: .5em;
    font-size: 0.8em;
}

#footer {
    margin:10px 12.5em 0px 0px;
}

#footer p, #footer form {
	margin: 0;
}


