/*  common.css - MoinMoin Default Styles

    Copyright (c) 2001, 2002, 2003 by Jürgen Hermann
*/

/* content styles */

html {
	background-color: white;
	color: black;
}

h1 {
        font-size: 1.6em;
}

h2 {
	font-size: 1.6em;
}

h3 {
	font-size: 1.3em;
}

h4, h5, h6 {
	font-size: 1em;
}

li p {
	margin: .2em 0;
}

li.gap {
    margin-top: 8pt;
}
    
a img {
	border: 0;
}

img.drawing {
	border: 0;
}

dt {
	font-weight: bold;
}

pre {
	padding: .5em;
}

/*#content {*/
    /* style for content generated by wiki markup */
/*}*/

.footnotes ul {
	padding: 0 2em;
	margin: 0 0 1em;
}

.footnotes li {
	list-style: none;
}

/* eye catchers */
.warning 
{
    color: #000000;
    background-color: #EDD097;
    padding: 1pt;
}

.error 
{
    color: #FF0000;
    background-color: #EDD097;
    padding: 1pt;
}

strong.highlight 
{
    background-color: #FFAA00;
    padding: 1pt;
}

