/*  print.css - MoinMoin Default Styles

    Copyright (c) 2001, 2002, 2003 by Jürgen Hermann
*/

/* content styles */

h2, h3, h4, h5, h6 {
	border-bottom: solid 1pt black;
}

a {
	background-color: inherit;
	color: inherit;
}

pre {
	border: 1pt solid black;
	background-color: inherit;
	color: black;
}

hr {
	clear: both;
	border-style: none;
	background-color: black;
	color: black;
	height: 1pt;
}

td {
	border: 1pt solid gray;
}

a.interwiki:before, a.badinterwiki:before {
	content: attr(title) ":";
}

a.interwiki img, a.badinterwiki img {
	display: none;
}

.footnotes div {
	width: 5em;
	border-top: 1pt solid black;
}

/* user interface styles */

h1 {
	padding: .2em 1em;
}

#logo {
	float: left;
	margin: 0 .5em;
}

*[dir="rtl"] #logo {
	float: right;
}

#title a {
	text-decoration: none;
}

#username, #navibar, #pagetrail, #iconbar, #message, #footer, #timings {
	display: none;
}

table.recentchanges {
	width: 100%;
}

.recentchanges td {
	padding: 0 .3em;
}

.rcdaybreak td {
	background-color: #CCCCFF;
	padding: .2em;
}

.rcicon1, .rcicon2 {
	text-align: center;
}

.rcpagelink {
	width: 33%;
}

.rctime {
	font-size: .9em;
	color: #4D4D4D;
}

.rceditor {
	color: green;
}

.rccomment {
	color: red;
	width: 66%;
}

.rcrss {
	float: right;
}

